pub trait Fetcher {
// Required method
fn fetch(&self, path: &str) -> Result<Vec<u8>>;
}Expand description
Pluggable transport for registry content.
Implementations return the raw bytes for a given registry-relative
path (e.g. /plugins/botan/index.toml). The default production
implementation will join these against the registry base URL and
perform an HTTP GET; tests use MemoryFetcher.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".